package
Version:
v0.0.0-...-b0046da
Opens a new window with list of versions in this module.
Published: Apr 11, 2026
License: BSD-3-Clause
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Attribute struct {
Value []byte `json:"value"`
Hash []byte `json:"hash"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.